@@ -1,10 +1,10 @@
 #!/bin/sh
 echo 'name: hslogger
-version: 1.1.5
-id: hslogger-1.1.5-13adda0b39a0331b6f8f7322430839f1
+version: 1.2.1
+id: hslogger-1.2.1-054aac0f9616db59c8b95c3621389d32
 
 license: BSD3
-copyright: Copyright (c) 2004-2011 John Goerzen
+copyright: Copyright (c) 2004-2012 John Goerzen
 maintainer: John Goerzen <jgoerzen@complete.org>
 stability: Stable
 homepage: http://software.complete.org/hslogger
@@ -27,27 +27,27 @@ exposed-modules: System.Log System.Log.Handler System.Log.Formatter
                  System.Log.Logger
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/hslogger-1.1.5
-library-dirs: /usr/local/lib/ghc/hslogger-1.1.5
-hs-libraries: HShslogger-1.1.5
+import-dirs: /usr/local/lib/ghc/hslogger-1.2.1
+library-dirs: /usr/local/lib/ghc/hslogger-1.2.1
+hs-libraries: HShslogger-1.2.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
-         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
-         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
-         old-locale-1.0.0.4-b1d945ebea59a524cba400a524cb40aa
-         process-1.1.0.1-c55e7a2b0eb5149f070b14e14bea1c83
-         time-1.4-b8e1c3d423daa1e2c5470a82caf23b52
-         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
+depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+         directory-1.2.0.1-5cea89dab5fade71d74e1fcf13ee5ca4
+         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
+         network-2.4.1.2-ed0143a4ea7fae0d6aafbe2cf30a6dc9
+         old-locale-1.0.0.5-753125cfaf463057d163a0cefde5b58f
+         process-1.1.0.2-a830d25f0e9fb9c610aa641b7f5b20f9
+         time-1.4.0.1-11ddabfbdd9e1882a9135b100d37881b
+         unix-2.6.0.1-f31936082e1fa9175b93ddf28f79644c
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hslogger-1.1.5/html/hslogger.haddock
-haddock-html: /usr/local/share/doc/hs-hslogger-1.1.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-hslogger-1.2.1/html/hslogger.haddock
+haddock-html: /usr/local/share/doc/hs-hslogger-1.2.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
